from peek_plugin_base.storage.DbConnection import DbSessionCreator
from peek_abstract_chunked_data_loader.private.server.admin_backend.AppSettingHandler import (
    makeAppSetttingsHandler,
)
from peek_abstract_chunked_data_loader.private.server.admin_backend.CustomAttrTableHandler import (
    makeCustomAttrTableHandler,
)
from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler

from peek_abstract_chunked_data_loader.private.server.admin_backend.CustomHeaderTableHandler import (
    makeCustomHeaderTableHandler,
)
from .SettingPropertyHandler import makeSettingPropertyHandler


def makeAdminBackendHandlers(
    dbSessionCreator: DbSessionCreator, observable: TupleDataObservableHandler
):
    yield makeAppSetttingsHandler(dbSessionCreator)

    yield makeSettingPropertyHandler(dbSessionCreator)

    yield makeCustomAttrTableHandler(observable, dbSessionCreator)
    yield makeCustomHeaderTableHandler(observable, dbSessionCreator)



from peek_plugin_base.server.PluginLogicEntryHookABC import PluginLogicEntryHookABC
from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
from peek_plugin_base.agent.PluginAgentEntryHookABC import PluginAgentEntryHookABC
from typing import Type

__version__ = '3.3.2'


def peekLogicEntryHook() -> Type[PluginLogicEntryHookABC]:
    from .private.server.LogicEntryHook import LogicEntryHook

    return LogicEntryHook


def peekAgentEntryHook() -> Type[PluginAgentEntryHookABC]:
    from .private.agent.AgentEntryHook import AgentEntryHook

    return AgentEntryHook
